@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package JSON::Schema::Modern; # git description: v0.527-10-g4314fc22
+package JSON::Schema::Modern; # git description: v0.528-9-g6e471c4e
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Validate data against a schema
 # KEYWORDS: JSON Schema data validation structure specification
 
-our $VERSION = '0.528';
+our $VERSION = '0.529';
 
 use 5.020;  # for fc, unicode_strings features
 use Moo;
@@ -17,14 +17,14 @@ no if "$]" >= 5.033001, feature => 'multidimensional';
 no if "$]" >= 5.033006, feature => 'bareword_filehandles';
 use JSON::MaybeXS;
 use Carp qw(croak carp);
-use List::Util 1.55 qw(pairs first uniqint pairmap);
+use List::Util 1.55 qw(pairs first uniqint pairmap uniq);
 use Ref::Util 0.100 qw(is_ref is_plain_hashref);
 use Mojo::URL;
 use Safe::Isa;
 use Path::Tiny;
 use Storable 'dclone';
 use File::ShareDir 'dist_dir';
-use Module::Runtime 'use_module';
+use Module::Runtime qw(use_module require_module);
 use MooX::TypeTiny 0.002002;
 use MooX::HandlesVia;
 use Types::Standard 1.010002 qw(Bool Int Str HasMethods Enum InstanceOf HashRef Dict CodeRef Optional slurpy ArrayRef Undef ClassName Tuple);
@@ -153,7 +153,7 @@ sub add_schema {
       errors => [ $document->errors ],
     )) if $document->has_errors;
 
-  if (not grep $_->{document} == $document, $self->_resource_values) {
+  if (not grep $_->{document} == $document, $self->_canonical_resources) {
     my $schema_content = $document->_serialized_schema
       // $document->_serialized_schema($self->_json_decoder->encode($document->schema));
 
@@ -161,7 +161,7 @@ sub add_schema {
           my $existing_content = $_->_serialized_schema
             // $_->_serialized_schema($self->_json_decoder->encode($_->schema));
           $existing_content eq $schema_content
-        } uniqint map $_->{document}, $self->_resource_values) {
+        } uniqint map $_->{document}, $self->_canonical_resources) {
       # we already have this schema content in another document object.
       $document = $existing_doc;
     }
@@ -179,6 +179,7 @@ sub add_schema {
         specification_version => $resource->{specification_version},
         vocabularies => $resource->{vocabularies},  # reference, not copy
         document => $document,
+        configs => $resource->{configs},
       });
   }
 
@@ -310,7 +311,7 @@ sub evaluate ($self, $data, $schema_reference, $config_override = {}) {
         schema => $document->schema,
         document => $document,
         document_path => '',
-        (map +($_ => $base_resource->{$_}), qw(canonical_uri specification_version vocabularies)),
+        (map +($_ => $base_resource->{$_}), qw(canonical_uri specification_version vocabularies configs)),
       };
     }
 
@@ -331,7 +332,7 @@ sub evaluate ($self, $data, $schema_reference, $config_override = {}) {
       vocabularies => $schema_info->{vocabularies},
       callbacks => $config_override->{callbacks} // {},
       evaluator => $self,
-      $schema_info->{document}->evaluation_configs->%*,
+      $schema_info->{configs}->%*,
       (map {
         my $val = $config_override->{$_} // $self->$_;
         defined $val ? ( $_ => $val ) : ()
@@ -544,6 +545,7 @@ has _resource_index => (
       document => InstanceOf['JSON::Schema::Modern::Document'],
       # the vocabularies used when evaluating instance data against schema
       vocabularies => ArrayRef[my $vocabulary_class_type = ClassName->where(q{$_->DOES('JSON::Schema::Modern::Vocabulary')})],
+      configs => HashRef,
       slurpy HashRef[Undef],  # no other fields allowed
     ]],
   handles_via => 'Hash',
@@ -554,7 +556,7 @@ has _resource_index => (
     _resource_index => 'elements',
     _resource_keys => 'keys',
     _add_resources_unsafe => 'set',
-    _resource_values => 'values',
+    _canonical_resources => 'values',
     _resource_exists => 'exists',
   },
   lazy => 1,
@@ -564,11 +566,12 @@ has _resource_index => (
 around _add_resources => sub {
   my ($orig, $self) = (shift, shift);
 
-  $resource_type->($_[1]) if @_;  # check type of hash value against Dict
-
   my @resources;
   foreach my $pair (sort { $a->[0] cmp $b->[0] } pairs @_) {
     my ($key, $value) = @$pair;
+
+    $resource_type->($value); # check type of hash value against Dict
+
     if (my $existing = $self->_get_resource($key)) {
       # we allow overwriting canonical_uri = '' to allow for ad hoc evaluation of schemas that
       # lack all identifiers altogether, but preserve other resources from the original document
@@ -753,7 +756,6 @@ sub _get_or_load_resource ($self, $uri) {
 
   # TODO:
   # - load from network or disk
-  # - handle such resources with $anchor fragments
 
   return;
 };
@@ -791,8 +793,7 @@ sub _fetch_from_uri ($self, $uri) {
         canonical_uri => $canonical_uri,
         document => $document,
         document_path => $document_path,
-        specification_version => $resource->{specification_version},
-        vocabularies => $resource->{vocabularies},  # reference, not copy
+        $resource->%{qw(specification_version vocabularies configs)}, # reference, not copy
       };
     }
   }
@@ -805,8 +806,7 @@ sub _fetch_from_uri ($self, $uri) {
         canonical_uri => $resource->{canonical_uri}->clone, # this is *not* the anchor-containing URI
         document => $resource->{document},
         document_path => $resource->{path},
-        specification_version => $resource->{specification_version},
-        vocabularies => $resource->{vocabularies},  # reference, not copy
+        $resource->%{qw(specification_version vocabularies configs)}, # reference, not copy
       };
     }
   }
@@ -860,6 +860,27 @@ has _encoding => (
   },
 );
 
+sub FREEZE ($self, $serializer) {
+  my $data = +{ %$self };
+  # Cpanel::JSON::XS doesn't serialize: https://github.com/Sereal/Sereal/issues/266
+  # coderefs can't serialize cleanly and must be re-added by the user.
+  delete $data->@{qw(_json_decoder _format_validations _media_type _encoding)};
+  return $data;
+}
+
+sub THAW ($class, $serializer, $data) {
+  my %bare_attrs = delete $data->%{qw(_resource_index _vocabulary_classes _metaschema_vocabulary_classes)};
+
+  my $self = $class->new($data);
+  $self->_add_resources_unsafe($bare_attrs{_resource_index}->%*);
+  $self->_set_vocabulary_class($bare_attrs{_vocabulary_classes}->%*);
+  $self->_set_metaschema_vocabulary_classes($bare_attrs{_metaschema_vocabulary_classes}->%*);
+
+  # load all vocabulary classes
+  require_module($_) foreach uniq map $_->{vocabularies}->@*, $self->_canonical_resources;
+  return $self;
+}
+
 1;
 
 __END__
@@ -876,7 +897,7 @@ JSON::Schema::Modern - Validate data against a schema
 
 =head1 VERSION
 
-version 0.528
+version 0.529
 
 =head1 SYNOPSIS
 
@@ -996,7 +1017,7 @@ Defaults to false.
 
 =head1 METHODS
 
-=for Pod::Coverage BUILDARGS
+=for Pod::Coverage BUILDARGS FREEZE THAW
 
 =head2 evaluate_json_string
 
